@@ -18,7 +18,7 @@ PROJECT = loads(Path("pyproject.toml").read_text("utf-8"))
 class FeatureGenerator:
     def __init__(self, feature_name: str) -> None:
         self.feature_path = (
-            curdir
+            Path(curdir)
             / PROJECT["tool"]["poetry"]["name"]
             / Path("api")
             / "features"
@@ -46,7 +46,11 @@ class FeatureGenerator:
 
     def create_test_file(self):
         (
-            Path("api") / "tests" / f"test_{self.feature_path.name.lower()}.py"
+            Path(curdir)
+            / PROJECT["tool"]["poetry"]["name"]
+            / Path("api")
+            / "tests"
+            / f"test_{self.feature_path.name.lower()}.py"
         ).write_text(
             templater.render(
                 "feature_test.py.j2", {"feature_name": self.feature_path.name.title()}
