@@ -18,7 +18,7 @@ PROJECT = loads(Path("pyproject.toml").read_text("utf-8"))
 class ModelGenerator:
     def __init__(self, model_name: str) -> None:
         self.model_path = (
-            curdir
+            Path(curdir)
             / PROJECT["tool"]["poetry"]["name"]
             / Path("api")
             / "models"
