@@ -19,7 +19,7 @@ PROJECT = loads(Path("pyproject.toml").read_text("utf-8"))
 class ServiceGenerator:
     def __init__(self, name: str, feature_name: str) -> None:
         self.service_name = (
-            curdir
+            Path(curdir)
             / PROJECT["tool"]["poetry"]["name"]
             / Path("api")
             / feature_name
